@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.027_01';
+our $VERSION = '0.027_02';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -417,7 +417,7 @@ sub dynamic_libs {
   if($class->install_type('system')) {
 
     my $name = $class->config('ffi_name');
-    unless(defined $name) {
+    if(defined $name) {
       $name = $class->config('name');
       # strip leading lib from things like libarchive or libffi
       $name =~ s/^lib//;
